==> XMLObject-0.0.2.tar.gz: XMLObject-0.0.2/tests/test.py <==
# Copyright (C) 2004 Philippe Normand <phil@respyre.org>
#
# This file is part of XMLObject (http://xmlobject.base-art.net)
#
# Under PSF Licence (see COPYING)

"""
    XMLObject's unit-tests

"""

import sys
sys.path.append('..')

from XMLObject import *
import unittest

False = 0!=0
True  = 0==0

class Item(XMLObject):
    record = StringAttribute()
    position = IntegerAttribute(facultative=False)
    content = TextNode()


class GetSetTest(unittest.TestCase):

    data = {'record':'AB1',
            'position':1,
            'content':'hey this is some content'}

    xmlData = """\
<Item record="AB1" position="1">
    hey this is some content
</Item>"""

    def setUp(self):
        self.obj = Item(**self.data)

    def testGet(self):
        self.assertEqual(self.obj.content,'hey this is some content')
        self.assertEqual(self.obj.position,1)
        self.assertEqual(self.obj.record, 'AB1')

    def testSet(self):
        self.obj.position = 4
        self.assertEqual(self.obj.position, 4)
        # really dummy :( Could use self.obj.set() instead  of setattr()
        self.assertRaises(TypeError, setattr, self.obj, 'position', 'not a number')
        self.assertRaises(TypeError, setattr, self.obj, 'record', 2)

    
class Playlist(XMLObject):
    name = StringAttribute()
    type = StringAttribute()
    items = ListNode('Item')

class GetSetTest2(unittest.TestCase):

    data = {'name':'foo',
            'type':'xml' }

    def setUp(self):
        self.obj = Playlist(**self.data)
        for i in range(10):
            self.obj.items.append(Item(position=i, content=chr(i)*5))

    def testGetList(self):
        self.assertEqual(len(self.obj.items), 10)
        for i in range(10):
            self.assertEqual(self.obj.items[i].position,i)

    def testSetList(self):
        class DummyItem(XMLObject): pass
        self.assertRaises(TypeError, self.obj.items.append, DummyItem())
        # XXX : add more here
    

class ImportExportTest(GetSetTest):

    def testImport(self):
        obj2 = Item()
        obj2.fromXml(self.xmlData)
        self.assertEqual(obj2, self.obj)
        
    def testExport(self):
        xml = self.obj.toXml(headers=0)
        self.assertEqual(xml, self.xmlData)
        
    def testExportImport(self):
        obj2 = Item()
        obj2.fromXml(self.obj.toXml())
        self.assertEqual(obj2, self.obj)

if __name__ == '__main__':
    unittest.main()

==> XMLObject-0.0.3.tar.gz: XMLObject-0.0.3/tests/test.py <==
# Copyright (C) 2004 Philippe Normand <phil@respyre.org>
#
# This file is part of XMLObject (http://xmlobject.base-art.net)
#
# Under PSF License (see COPYING)

"""
    XMLObject's unit-tests

"""

import sys
sys.path.append('..')

from XMLObject import *
import unittest

False = 0!=0
True  = 0==0

class Item(XMLObject):
    record = StringAttribute()
    position = IntegerAttribute(facultative=False)
    content = TextNode()


class GetSetTest(unittest.TestCase):

    data = {'record':'AB1',
            'position':1,
            'content':'hey this is some content'}

    xmlData = """\
<item record="AB1" position="1">
  hey this is some content
</item>"""

    def setUp(self):
        self.obj = Item(**self.data)

    def testGet(self):
        self.assertEqual(self.obj.content,'hey this is some content')
        self.assertEqual(self.obj.position,1)
        self.assertEqual(self.obj.record, 'AB1')

    def testSet(self):
        self.obj.position = 4
        self.assertEqual(self.obj.position, 4)
        # really dummy :( Could use self.obj.set() instead  of setattr()
        self.assertRaises(TypeError, setattr, self.obj, 'position', 'not a number')
        self.assertRaises(TypeError, setattr, self.obj, 'record', 2)

    
class Playlist(XMLObject):
    name = StringAttribute()
    type = StringAttribute()
    items = ListNode('Item')

class GetSetTest2(unittest.TestCase):

    data = {'name':'foo',
            'type':'xml' }

    def setUp(self):
        self.obj = Playlist(**self.data)
        for i in range(10):
            self.obj.items.append(Item(position=i, content=chr(i)*5))

    def testGetList(self):
        self.assertEqual(len(self.obj.items), 10)
        for i in range(10):
            self.assertEqual(self.obj.items[i].position,i)

    def testSetList(self):
        class DummyItem(XMLObject): pass
        self.assertRaises(TypeError, self.obj.items.append, DummyItem())
        it = Item(position=0, content='Foo Bar')
        self.obj.items = [ it ]
        self.assertEqual(self.obj.items[0], it)

class ImportExportTest(GetSetTest):

    def testImport(self):
        obj2 = Item.fromXml(self.xmlData)
        self.assertEqual(obj2, self.obj)
        
    def testExport(self):
        xml = self.obj.toXml(headers=0)
        self.assertEqual(xml, self.xmlData)
        
    def testExportImport(self):
        obj2 = Item.fromXml(self.obj.toXml())
        self.assertEqual(obj2, self.obj)

class InheritanceTest(unittest.TestCase):

    def testInheritSimple(self):

        class MyPlaylist(Playlist):
            def getName(self):
                return 'ma playlist a moi'

        class AnotherPlaylist(Playlist):
            description = TextNode()

        self.assertRaises(TypeError, MyPlaylist)
        pl = AnotherPlaylist(name='test', type='xml')
        pl.description = "This is the playlist description"
        self.assertEqual(pl.name, 'test')
        self.assertEqual(pl.type, 'xml')
        self.assertEqual(pl.items, [])
        self.assertEqual(pl.description,"This is the playlist description" )

    def testMultipleInherit(self):
        
        class Dummy:
            def getName(self):
                return 'foo bar'

        class MyOtherPlaylist(Playlist, Dummy):
            pass

        self.assertRaises(TypeError, MyOtherPlaylist)
        

if __name__ == '__main__':
    unittest.main()
